@@ -5,7 +5,6 @@ import logging
 import re
 from datetime import date
 from datetime import datetime as dt
-from datetime import timedelta
 from typing import Any, Optional, Tuple
 
 import pandas as pd
@@ -30,8 +29,11 @@ class EnedisAnalytics:
         groupby: str | None = None,
         freq: str = "H",
         summary: bool = False,
+        cumsum: float = 0,
     ) -> Any:
         """Convert datas to analyze."""
+        if self.df.empty:
+            return self.df.to_dict(orient="records")
         if convertKwh:
             self.df["interval_length"] = self.df["interval_length"].transform(
                 self._weighted_interval
@@ -45,7 +47,9 @@ class EnedisAnalytics:
             )
 
         if intervals:
-            resultat = self._get_data_interval(intervals, groupby, freq, summary)
+            resultat = self._get_data_interval(
+                intervals, groupby, freq, summary, cumsum
+            )
             return resultat[0].to_dict("records"), resultat[1].to_dict("records")
         else:
             return self.df.to_dict(orient="records")
@@ -62,7 +66,8 @@ class EnedisAnalytics:
         groupby: str | None = None,
         freq: str = "H",
         summary: bool = False,
-    ) -> Tuple[Any, Any]:
+        cumsum: float = 0,
+    ) -> pd.DataFrame:
         """Group date from range time.
 
         Returns a tuple
@@ -77,7 +82,7 @@ class EnedisAnalytics:
             ]
             in_df = pd.concat([in_df, df2], ignore_index=True)
 
-        out_df = self.df[~self.df.isin(in_df)].dropna()
+        # out_df = self.df[~self.df.isin(in_df)].dropna()
 
         if groupby:
             in_df = (
@@ -87,23 +92,29 @@ class EnedisAnalytics:
             )
             in_df = in_df[in_df.value != 0]
 
-            out_df = (
-                out_df.groupby(pd.Grouper(key="date", freq="H"))["value"]
-                .sum()
-                .reset_index()
-            )
+            # out_df = (
+            #     out_df.groupby(pd.Grouper(key="date", freq="H"))["value"]
+            #     .sum()
+            #     .reset_index()
+            # )
 
         if summary:
-            in_df["sum_value"] = in_df.value.cumsum()
-            out_df["sum_value"] = out_df.value.cumsum()
+            in_df["sum_value"] = in_df.value.cumsum() + cumsum
+            # out_df["sum_value"] = out_df.value.cumsum() + cumsum
 
-        return in_df, out_df
+        # return in_df, out_df
+        return in_df
 
     def set_price(
-        self, data: dict[str, Any], price: float, summary: bool = False
+        self,
+        data: dict[str, Any],
+        price: float,
+        summary: bool = False,
     ) -> Any:
         """Set prince."""
         df = pd.DataFrame(data)
+        if df.empty:
+            return df.to_dict(orient="records")
         df["price"] = df["value"] * price
         if summary:
             df["sum_price"] = df["price"].cumsum()
@@ -137,6 +148,7 @@ class EnedisByPDL:
         self.tempo_day: str | None = None
         self.ecowatt: dict[str, Any] = {}
         self.valid_access: dict[str, Any] = {}
+        self.models: list[Tuple[str, dt, dt]] = []
 
     async def async_fetch_datas(
         self, service: str, start: dt | None = None, end: dt | None = None
@@ -252,50 +264,26 @@ class EnedisByPDL:
         """Close session."""
         await self.auth.async_close()
 
-    async def async_load(
-        self,
-        start: dt = dt.now() - timedelta(days=7),
-        end: dt = dt.now(),
-        daily: bool = False,
-    ) -> None:
-        """Retrieves production and consumption data."""
-        self.valid_access = await self.async_valid_access()
-        if daily:
-            c_datas = await self.async_get_daily_consumption(start, end)
-            self.power_datas.update(
-                {
-                    "daily_consumption": c_datas.get("meter_reading", {}).get(
-                        "interval_reading"
-                    )
-                }
-            )
-            if self.b_production:
-                p_datas = await self.async_get_daily_production(start, end)
-                self.power_datas.update(
-                    {
-                        "daily_production": p_datas.get("meter_reading", {}).get(
-                            "interval_reading"
-                        )
-                    }
-                )
+    async def async_load(self, models: list[Tuple[str, dt, dt]] | None = None) -> None:
+        """Retrieves production and consumption data.
+
+        models , list contain tuple
+        tuple : service (string) , start (datetime) , end (datetime)
+        """
+        if models is None:
+            models = self.models
         else:
-            c_datas = await self.async_get_details_consumption(start, end)
+            self.models = models
+        self.valid_access = await self.async_valid_access()
+        self.power_datas = {}
+        for model in models:
+            service = model[0]
+            start = model[1]
+            end = model[2]
+            datas = await self.async_fetch_datas(service, start, end)
             self.power_datas.update(
-                {
-                    "consumption_load_curve": c_datas.get("meter_reading", {}).get(
-                        "interval_reading"
-                    )
-                }
+                {service: datas.get("meter_reading", {}).get("interval_reading")}
             )
-            if self.b_production:
-                p_datas = await self.async_get_details_production(start, end)
-                self.power_datas.update(
-                    {
-                        "production_load_curve": p_datas.get("meter_reading", {}).get(
-                            "interval_reading"
-                        )
-                    }
-                )
 
         if self.last_refresh_date is None or dt.now().date() > self.last_refresh_date:
             await self.async_get_contract()
